@@ -1430,7 +1430,9 @@ static int vo_get_property (xine_video_port_t *this_gen, int property) {
   case XINE_PARAM_VO_HUE:
   case XINE_PARAM_VO_SATURATION:
   case XINE_PARAM_VO_CONTRAST:
-  case XINE_PARAM_VO_BRIGHTNESS: {
+  case XINE_PARAM_VO_BRIGHTNESS:
+  case XINE_PARAM_VO_GAMMA:
+   {
     int v, min_v, max_v, range_v;
 
     pthread_mutex_lock( &this->driver_lock );
@@ -1523,6 +1525,7 @@ static int vo_set_property (xine_video_port_t *this_gen, int property, int value
   case XINE_PARAM_VO_SATURATION:
   case XINE_PARAM_VO_CONTRAST:
   case XINE_PARAM_VO_BRIGHTNESS:
+  case XINE_PARAM_VO_GAMMA:
     if (!this->grab_only) {
       int v, min_v, max_v, range_v;
 
@@ -1908,7 +1911,9 @@ xine_video_port_t *_x_vo_new_port (xine_t *xine, vo_driver_t *driver, int grabon
     this->grab_only            = 0;
 
     pthread_attr_init(&pth_attrs);
+#ifdef _POSIX_THREAD_PRIORITY_SCHEDULING
     pthread_attr_setscope(&pth_attrs, PTHREAD_SCOPE_SYSTEM);
+#endif
 
     if ((err = pthread_create (&this->video_thread,
 			       &pth_attrs, video_out_loop, this)) != 0) {
